#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# (C) Copyright 2009, Markus Korn <thekorn@gmx.de>
#
# ##################################################################
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ##################################################################

import os
import sys
import nautilus

from urllib import url2pathname
from urlparse import urlparse

try:
    from zeitgeistfs import utils
except ImportError:
    path = os.environ.get("ZEITGEISTFS_PATH", None)
    if path is None:
        utils = None
    else:
        sys.path.insert(0, path)
        try:
            from zeitgeistfs import utils
        except ImportError, e:
            print e
            utils = None
    
ANNOTATIONS_CACHE = {}

class ZeitgeistInfoProvider(nautilus.InfoProvider):
    
    def __init__(self, *args, **kwargs):
        pass
    
    def update_file_info(self, file):
        """Returns either None or an int to update the file information.

        @param file: the file to update the status of
        @return: int or None
        """
        if utils is None:
            return 0
        filename = url2pathname(urlparse(file.get_uri()).path)
        dirname, filename = os.path.split(filename)
        if dirname not in ANNOTATIONS_CACHE:
            try:
                annotations = utils.read_annotations_for_dir(dirname)
            except TypeError:
                return 0
            ANNOTATIONS_CACHE[dirname] = annotations
        file_annotations = ANNOTATIONS_CACHE[dirname].get(filename, None)
        if file_annotations:
            if file_annotations["bookmarked"]:
                file.add_emblem("star")
            if "share" in file_annotations["tags"]:
                # just as a test, maybe filter by user tags here
                file.add_emblem("shared")
