#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# (C) Copyright 2009, Markus Korn <thekorn@gmx.de>
#
# ##################################################################
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ##################################################################

# can we use xdg.DesktopEntry here?
# - can we add a shebang with it
# - can we dump content to StringIO instead of file?
# - or do we want to create tempfiles for each .desktop entry
# SafeConfigParser also sucks, because it ignores cases

from cStringIO import StringIO
        
class DesktopFile(object):
        
    ## Sample .desktop file
    #~ #!/usr/bin/env xdg-open
    #~ 
    #~ [Desktop Entry]
    #~ Version=1.0
    #~ Type=Link
    #~ Icon[de_DE]=gnome-panel-launcher
    #~ Name[de_DE]=file:///test/dfg/fg tt.tex
    #~ URL=file:///home/markus/test.html
    #~ Name=file:///test/dfg/fg tt.tex
    #~ Icon=gnome-panel-launcher
        
    def __init__(self, uri, type, name=None, icon=None):
        name = name or uri
        self.__data = {
            "Version": "1.0",
            "Type": str(type),
            "URL": str(uri),
            "Name": str(name.encode("UTF-8", "replace")),
        }
        if icon is not None:
            self.__data["Icon"] = str(icon)
        
    def write(self, fileobject=None):
        if fileobject is None:
            fileobject = StringIO()
        fileobject.write("[Desktop Entry]\n")
        for key, value in self.__data.iteritems():
            fileobject.write("%s = %s\n" %(key, value))
        return fileobject

        
class StarterLink(DesktopFile):
        
    def __init__(self, uri, name):
        super(StarterLink, self).__init__(uri, "Link", name)
        
    def write(self, fileobject=None):
        if fileobject is None:
            fileobject = StringIO()
        fileobject.write("#!/usr/bin/env xdg-open\n\n\n")
        return super(StarterLink, self).write(fileobject)
        

class WWWLink(DesktopFile):
    
    #~ [Desktop Entry]
    #~ Name=Verknüpfung mit Ubuntu-Startseite
    #~ Type=Link
    #~ URL=http://start.ubuntu.com/9.04/
    #~ Icon=gnome-fs-bookmark
    
    def __init__(self, uri, name):
        super(WWWLink, self).__init__(uri, "Link", name, "gnome-fs-bookmark")
    
