import time
import string
import random
import atexit
import shutil
import tempfile
import os
from datetime import datetime

TEMPDIR = tempfile.mkdtemp()
atexit.register(shutil.rmtree, TEMPDIR)

def get_random_uri():
    fd, path = tempfile.mkstemp(dir=TEMPDIR, text=True)
    os.close(fd)
    return "file://%s" %path
    
def get_random_text(max_length=50):
    return "".join(random.sample(string.printable, random.randint(1, max_length)))

def make_timestamp(*args):
    d = datetime(*args)
    return int(time.mktime(d.timetuple()))
    
def exists_or_create(path):
    p = "/%s" %path.split("///", 1)[-1].lstrip("/")
    assert p.startswith(TEMPDIR)
    if not os.path.exists(p):
        f = open(p, "w+")
        f.close()
    return path
    
def make_item(timetuple, uri=None, text=None):
    return dict(
        timestamp=make_timestamp(*timetuple),
        uri=exists_or_create(uri or get_random_uri()),
        text=text or get_random_text(),
    )

class DataFixture(dict):
    
    ITEMS = [
        make_item((2009, 1, 1, 10, 20)),
        make_item((2009, 1, 1, 11, 15), "file://%s" %os.path.join(TEMPDIR, "abcd.ext")),
        make_item((2009, 1, 1, 12, 30), "file://%s" %os.path.join(TEMPDIR, "test filename")),
        make_item((2008, 12, 31)),
        make_item((2009, 1, 2, 0, 30)),
        make_item((2009, 1, 7)), #newest one
        make_item((2008, 12, 25)), #oldest one
    ]
    
    def __init__(self):
        super(DataFixture, self).__init__()
        self[(0, 0, 1, True, "item")] = [DataFixture.ITEMS[-1],]
        self[(0, 0, 1, False, "item")] = [DataFixture.ITEMS[-2],]
        self[(
            make_timestamp(2009, 1, 1),
            make_timestamp(2009, 1, 2),
            0, True, "item" 
        )] = DataFixture.ITEMS[:3]
        
    def __getitem__(self, key):
        if len(key) == 6:
            key = tuple(key[:-1])
        try:
            return super(DataFixture, self).__getitem__(key)
        except KeyError:
            return []

DATA = DataFixture()
