import unittest
import os.path
import datetime

from zeitgeistfs import fselements

class FakeInterface(object):
    
    def __init__(self):
        from _engine_fixture import DATA
        self.__fixture = DATA
    
    def FindEvents(self, *args):
        return self.__fixture[args]
        
fselements._IFACE = FakeInterface()
    
from _engine_fixture import TEMPDIR

TEMPDIR_PREFIX = TEMPDIR.replace("/", "_").lstrip("_")

class TestRoot(unittest.TestCase):
    
    def setUp(self):
        self.__root = fselements.Root("/boo/bar/baz", desktop=True)
    
    def test_root(self):
        self.assertTrue(isinstance(self.__root, fselements.Root))
        self.assertEqual(self.__root.name, "/")
        self.assertEqual(set(self.__root.get_items()), set([".", "..", "today.desktop", "journal"]))
        self.assertEqual(self.__root["/"], self.__root)
        
    def test_journal(self):
        journal = self.__root["/journal"]
        self.assertTrue(isinstance(journal, fselements.Journal))
        self.assertEqual(set(journal.get_items()), set([".", "..", "2008", "2009"]))
        
    def test_year(self):
        journal = self.__root["/journal"]
        self.assertTrue(isinstance(self.__root["/journal/2009"], fselements.Year))
        self.assertEqual(self.__root["/journal/2009"], journal["/journal/2009"])
        ## the following two will no work
        ## because the range of shown elements is dynamic
        ## and depends on date.today()
        ## maybe we can change the year from 2009 to 2008 to work around this
        #~ self.assertEqual(len(self.__root["/journal/2009"]), 14)
        #~ self.assertEqual(
            #~ set(self.__root["/journal/2009"].get_items()),
            #~ set([".", ".."] + ["%.2i" %i for i in range(1, 13)])
        #~ )
        
    def test_month(self):
        self.assertTrue(isinstance(self.__root["/journal/2009/6"], fselements.Month))
        self.assertEqual(self.__root["/journal/2009/6"], self.__root["/journal/2009/06"])
        self.assertEqual(len(self.__root["/journal/2009/1"]), 33)
        self.assertTrue(isinstance(self.__root["/journal/2009/6/1"], fselements.Day))
        
    def test_day(self):
        self.assertTrue(isinstance(self.__root["/journal/2009/1/1"], fselements.Day))
        day = self.__root["/journal/2009/1/1"]
        self.assertEqual(len(day), 5, day.get_items())
        self.assertTrue("%s_test filename" %TEMPDIR_PREFIX in day.get_items(), day.get_items())
        self.assertTrue(
            isinstance(
                self.__root["/journal/2009/1/1/%s_test filename" %TEMPDIR_PREFIX],
                fselements.File
            )
        )
        self.assertTrue(
            isinstance(
                self.__root["/journal/2009/1/1/%s_abcd.ext" %TEMPDIR_PREFIX],
                fselements.File
            )
        )
        day = self.__root["/journal/2008/12/30"]
        self.assertEqual(len(day), 2, day.get_items())
        
    def test_timeperiod(self):
        self.assertRaises(OSError, self.__root.__getitem__, "/journal/1999/1/1")
        self.assertRaises(OSError, self.__root.__getitem__, "/journal/2010/1/1")
                
    def test_today(self):
        today = self.__root["/today.desktop"]
        date_today = datetime.date.today()
        self.assertTrue(isinstance(today, fselements.Today))
        content = today.read(1000000, 0)
        path = os.path.sep.join(["%.2i" %i for i in date_today.timetuple()[:3]])
        self.assertTrue(path in content)
